==> haskell-ipynb-0.2-136-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-6uBUynvgNgx7TJUSjD2xqJ
key:                  ipynb-0.2-6uBUynvgNgx7TJUSjD2xqJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  8b5d5b3fc0ccef21a8e8479a6993343e
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-6uBUynvgNgx7TJUSjD2xqJ
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8 base-4.16.4.0
    base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    bytestring-0.11.4.0 containers-0.6.5.1 text-1.2.5.0
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.2-145-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.2
visibility:           public
id:                   ipynb-0.2-E7ZAKgiBbLbK1Y679w8q0q
key:                  ipynb-0.2-E7ZAKgiBbLbK1Y679w8q0q
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  dee055bbd73dfe0d5c3d52792e42db09
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ipynb-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ipynb-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ipynb
hs-libraries:         HSipynb-0.2-E7ZAKgiBbLbK1Y679w8q0q
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj bytestring-0.11.4.0
    containers-0.6.5.1 text-1.2.5.0
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
